@@ -5,8 +5,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2004-2011                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "javacodeclassfielddeclarationblock.h"
@@ -51,7 +51,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent()
     getComment()->setText(notes);
 
     // Set the body
-    QString staticValue = getParentObject()->isStatic() ? QLatin1String("static ") : QString();
+    QString staticValue = getParentObject()->isStatic() ? "static " : "";
     QString scopeStr = Uml::Visibility::toString(getParentObject()->visibility());
 
     // IF this is from an association, then scope taken as appropriate to policy
@@ -75,17 +75,17 @@ void JavaCodeClassFieldDeclarationBlock::updateContent()
     QString initialV = jcf->getInitialValue();
 
     if (!cf->parentIsAttribute() && !cf->fieldIsSingleValue())
-        typeName = QLatin1String("List");
+        typeName = "List";
 
-    QString body = staticValue+scopeStr+QLatin1Char(' ')+typeName+QLatin1Char(' ')+fieldName;
+    QString body = staticValue+scopeStr+' '+typeName+' '+fieldName;
     if (!initialV.isEmpty())
-        body.append(QLatin1String(" = ") + initialV);
+        body.append(" = " + initialV);
     else if (!cf->parentIsAttribute())
     {
         UMLRole * role = dynamic_cast<UMLRole*>(cf->getParentObject());
         if (role->object()->baseType() == UMLObject::ot_Interface)
         {
-            // do nothing.. can't instantiate an interface
+            // do nothing.. can't instanciate an interface
         } else {
 
             // FIX?: IF a constructor method exists in the classifiercodedoc
@@ -93,12 +93,13 @@ void JavaCodeClassFieldDeclarationBlock::updateContent()
             if(cf->fieldIsSingleValue())
             {
                 if(!typeName.isEmpty())
-                    body.append(QLatin1String(" = new ") + typeName + QLatin1String(" ()"));
+                    body.append(" = new " + typeName + " ( )");
             } else
-                body.append(QLatin1String(" = new Vector ()"));
+                body.append(" = new Vector ( )");
         }
     }
 
-    setText(body+QLatin1Char(';'));
+    setText(body+';');
 }
 
+#include "javacodeclassfielddeclarationblock.moc"
