@@ -5,15 +5,15 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2004-2012                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "simplecodegenerator.h"
 
 // app includes
-#include "overwritedialog.h"
+#include "overwritedialogue.h"
 #include "model_utils.h"
 #include "attribute.h"
 #include "umloperationlist.h"
@@ -26,14 +26,12 @@
 #include "uml.h"
 
 // kde includes
-#if QT_VERSION < 0x050000
+#include <klocale.h>
+#include <kmessagebox.h>
 #include <kdialog.h>
-#endif
-#include <KLocalizedString>
-#include <KMessageBox>
+#include <kapplication.h>
 
 // qt includes
-#include <QApplication>
 #include <QDateTime>
 #include <QDir>
 #include <QPointer>
@@ -97,25 +95,25 @@ QString SimpleCodeGenerator::findFileName(UMLPackage* concept, const QString &ex
     //else, determine the "natural" file name
     QString name;
     // Get the package name
-    QString package = concept->package(QLatin1String("."));
+    QString package = concept->package(".");
 
     // Replace all white spaces with blanks
     package = package.simplified();
 
     // Replace all blanks with underscore
-    package.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
+    package.replace(QRegExp(" "), "_");
 
     // Convert all "::" to "/" : Platform-specific path separator
-    // package.replace(QRegExp(QLatin1String("::")), QLatin1String("/"));
+    // package.replace(QRegExp("::"), "/");
 
     // if package is given add this as a directory to the file name
     if (!package.isEmpty() && m_createDirHierarchyForPackages) {
-        name = package + QLatin1Char('.') + concept->name();
-        name.replace(QRegExp(QLatin1String("\\.")), QLatin1String("/"));
-        package.replace(QRegExp(QLatin1String("\\.")), QLatin1String("/"));
-        package = QLatin1Char('/') + package;
+        name = package + '.' + concept->name();
+        name.replace(QRegExp("\\."),"/");
+        package.replace(QRegExp("\\."), "/");
+        package = '/' + package;
     } else {
-        name = concept->fullyQualifiedName(QLatin1String("-"));
+        name = concept->fullyQualifiedName("-");
     }
 
     if (! UMLApp::app()->activeLanguageIsCaseSensitive()) {
@@ -129,30 +127,30 @@ QString SimpleCodeGenerator::findFileName(UMLPackage* concept, const QString &ex
         // does our complete output directory exist yet? if not, try to create it
         if (!pathDir.exists())
         {
-            const QStringList dirs = pathDir.absolutePath().split(QLatin1Char('/'));
-            QString currentDir;
+            const QStringList dirs = pathDir.absolutePath().split('/');
+            QString currentDir = "";
 
             QStringList::const_iterator end(dirs.end());
             for (QStringList::const_iterator dir(dirs.begin()); dir != end; ++dir)
             {
-                currentDir += QLatin1Char('/') + *dir;
+                currentDir += '/' + *dir;
                 if (! (pathDir.exists(currentDir)
-                        || pathDir.mkdir(currentDir)))
+                        || pathDir.mkdir(currentDir) ) )
                 {
                     KMessageBox::error(0, i18n("Cannot create the folder:\n") +
                                        pathDir.absolutePath() + i18n("\nPlease check the access rights"),
                                        i18n("Cannot Create Folder"));
-                    return QString();
+                    return NULL;
                 }
             }
         }
     }
 
     name = name.simplified();
-    name.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
+    name.replace(QRegExp(" "),"_");
 
     QString extension = ext.simplified();
-    extension.replace(QLatin1Char(' '), QLatin1Char('_'));
+    extension.replace(' ', '_');
 
     return overwritableName(concept, name, extension);
 }
@@ -169,60 +167,48 @@ QString SimpleCodeGenerator::overwritableName(UMLPackage* concept, const QString
     CodeGenerationPolicy *commonPolicy = UMLApp::app()->commonPolicy();
     QDir outputDir = commonPolicy->getOutputDirectory();
     QString filename = name + ext;
-    if (!outputDir.exists(filename)) {
-        m_fileMap.insert(concept, filename);
+    if(!outputDir.exists(filename)) {
+        m_fileMap.insert(concept,filename);
         return filename; //if not, "name" is OK and we have not much to to
     }
 
     int suffix;
-    QPointer<OverwriteDialog> overwriteDialog =
-        new OverwriteDialog(filename, outputDir.absolutePath(),
-                              m_applyToAllRemaining, qApp->activeWindow());
+    QPointer<OverwriteDialogue> overwriteDialogue =
+        new OverwriteDialogue(filename, outputDir.absolutePath(),
+                              m_applyToAllRemaining, kapp->activeWindow());
     switch(commonPolicy->getOverwritePolicy()) {  //if it exists, check the OverwritePolicy we should use
     case CodeGenerationPolicy::Ok:                //ok to overwrite file
         break;
     case CodeGenerationPolicy::Ask:               //ask if we can overwrite
-        switch(overwriteDialog->exec()) {
-#if QT_VERSION >= 0x050000
-        case OverwriteDialog::Ok:  //overwrite file
-#else
-        case QDialog::Accepted:
-#endif
-            if (overwriteDialog->applyToAllRemaining()) {
+        switch(overwriteDialogue->exec()) {
+        case KDialog::Yes:  //overwrite file
+            if ( overwriteDialogue->applyToAllRemaining() ) {
                 commonPolicy->setOverwritePolicy(CodeGenerationPolicy::Ok);
             } else {
                 m_applyToAllRemaining = false;
             }
             break;
-#if QT_VERSION >= 0x050000
-        case OverwriteDialog::No: //generate similar name
-#else
-        case KDialog::No:
-#endif
+        case KDialog::No: //generate similar name
             suffix = 1;
             while (1) {
-                filename = name + QLatin1String("__") + QString::number(suffix) + ext;
+                filename = name + "__" + QString::number(suffix) + ext;
                 if (!outputDir.exists(filename))
                     break;
                 suffix++;
             }
-            if (overwriteDialog->applyToAllRemaining()) {
+            if ( overwriteDialogue->applyToAllRemaining() ) {
                 commonPolicy->setOverwritePolicy(CodeGenerationPolicy::Never);
             } else {
                 m_applyToAllRemaining = false;
             }
             break;
-#if QT_VERSION >= 0x050000
-        case OverwriteDialog::Cancel: //don't output anything
-#else
-        case QDialog::Rejected:
-#endif
-            if (overwriteDialog->applyToAllRemaining()) {
+        case KDialog::Cancel: //don't output anything
+            if ( overwriteDialogue->applyToAllRemaining() ) {
                 commonPolicy->setOverwritePolicy(CodeGenerationPolicy::Cancel);
             } else {
                 m_applyToAllRemaining = false;
             }
-            delete overwriteDialog;
+            delete overwriteDialogue;
             return QString();
             break;
         }
@@ -230,20 +216,20 @@ QString SimpleCodeGenerator::overwritableName(UMLPackage* concept, const QString
     case CodeGenerationPolicy::Never: //generate similar name
         suffix = 1;
         while (1) {
-            filename = name + QLatin1String("__") + QString::number(suffix) + ext;
+            filename = name + "__" + QString::number(suffix) + ext;
             if (!outputDir.exists(filename))
                 break;
             suffix++;
         }
         break;
     case CodeGenerationPolicy::Cancel: //don't output anything
-        delete overwriteDialog;
+        delete overwriteDialogue;
         return QString();
         break;
     }
 
     m_fileMap.insert(concept, filename);
-    delete overwriteDialog;
+    delete overwriteDialogue;
     return filename;
 }
 
@@ -255,8 +241,8 @@ QString SimpleCodeGenerator::overwritableName(UMLPackage* concept, const QString
 bool SimpleCodeGenerator::hasDefaultValueAttr(UMLClassifier *c)
 {
     UMLAttributeList atl = c->getAttributeList();
-    foreach (UMLAttribute* at, atl) {
-        if (!at->getInitialValue().isEmpty())
+    foreach (UMLAttribute* at, atl ) {
+        if(!at->getInitialValue().isEmpty())
             return true;
     }
     return false;
@@ -270,8 +256,8 @@ bool SimpleCodeGenerator::hasDefaultValueAttr(UMLClassifier *c)
 bool SimpleCodeGenerator::hasAbstractOps(UMLClassifier *c)
 {
     UMLOperationList opl(c->getOpList());
-    foreach (UMLOperation* op, opl) {
-        if (op->isAbstract())
+    foreach (UMLOperation* op, opl ) {
+        if(op->isAbstract())
             return true;
     }
     return false;
@@ -294,8 +280,12 @@ CodeDocument * SimpleCodeGenerator::newClassifierCodeDocument(UMLClassifier* cla
  */
 void SimpleCodeGenerator::writeCodeToFile()
 {
+    m_fileMap.clear(); // need to do this, else just keep getting same directory to write to.
     UMLClassifierList concepts = m_document->classesAndInterfaces();
-    writeCodeToFile(concepts);
+    foreach (UMLClassifier* c, concepts ) {
+        if (! Model_Utils::isCommonDataType(c->name()))
+            this->writeClass(c); // call the writer for each class.
+    }
 }
 
 /**
@@ -306,10 +296,8 @@ void SimpleCodeGenerator::writeCodeToFile(UMLClassifierList & concepts)
 {
     m_fileMap.clear(); // ??
     foreach (UMLClassifier* c, concepts) {
-        if (! Model_Utils::isCommonDataType(c->name()))
-            this->writeClass(c); // call the writer for each class.
+        this->writeClass(c); // call the writer for each class.
     }
-    finalizeRun();
 }
 
 /**
@@ -332,3 +320,4 @@ void SimpleCodeGenerator::initFromParentDocument()
     // do nothing
 }
 
+#include "simplecodegenerator.moc"
